#
# spec file for package konstraint
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           konstraint
Version:        0.43.0
Release:        1.1
Summary:        A policy management tool for interacting with Gatekeeper
License:        Apache-2.0
URL:            https://github.com/plexsystems/konstraint
Source:         konstraint-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Konstraint is a CLI tool to assist with the creation and management of
templates and constraints when using Gatekeeper.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -ldflags="-X github.com/plexsystems/konstraint/internal/commands.version=%{version}"

%install
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}

%check
%{buildroot}/%{_bindir}/%{name} --version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Jun 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.43.0:
  * build(deps): bump golang from 1.24.2-alpine to 1.24.4-alpine
    (#631)
  * build(deps): bump golang.org/x/text from 0.24.0 to 0.26.0
    (#630)
  * build(deps): bump alpine from 3.21.3 to 3.22.0 (#627)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.33.0 to
    0.33.1 (#624)
  * build(deps): bump github.com/open-policy-agent/opa from 1.4.2
    to 1.5.1 (#629)
  * ci: Do a full clone in the release workflow (#620)
* Mon May  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.42.0:
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.32.3 to
    0.33.0 (#616)
  * build(deps): bump github.com/open-policy-agent/opa from 1.3.0
    to 1.4.2 (#619)
  * feat: Remove support for legacy annotations (#555)
  * build(deps): bump golang.org/x/net from 0.37.0 to 0.38.0 (#615)
  * build(deps): bump golang from 1.24.1-alpine to 1.24.2-alpine
    (#614)
  * build(deps): bump golang.org/x/text from 0.23.0 to 0.24.0
    (#613)
  * chore: Upgrade to golangci-lint v2 (#612)
  * build(deps): bump github.com/spf13/viper from 1.19.0 to 1.20.1
    (#610)
  * build(deps): bump github.com/open-policy-agent/opa from 1.2.0
    to 1.3.0 (#611)
  * build(deps): bump golang.org/x/text from 0.22.0 to 0.23.0
    (#603)
  * build(deps): bump golang.org/x/net from 0.35.0 to 0.36.0 (#607)
  * build(deps): bump golang from 1.24.0-alpine to 1.24.1-alpine
    (#604)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.32.2 to
    0.32.3 (#605)
  * fix(goreleaser): Fix deprecated config (#599)
* Sun Mar  2 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.41.0:
  * build(deps): bump github.com/open-policy-agent/opa from 1.1.0
    to 1.2.0 (#594)
  * ci: Remove E2E prep dependency on acceptance tests (#596)
  * build: Bump Go to 1.24 (#595)
  * build(deps): bump alpine from 3.21.2 to 3.21.3 (#589)
  * build(deps): bump github.com/google/go-cmp from 0.6.0 to 0.7.0
    (#592)
  * build(deps): bump github.com/spf13/cobra from 1.8.1 to 1.9.1
    (#590)
  * build(deps): bump golang from 1.23.6-alpine to 1.24.0-alpine
    (#588)
  * Fix constraint template when the matchers key is not present
    (#591)
  * Add goreleaser to publish binaries (#579)
  * feat: Make policy available in doc command (#593)
  * Lint/improve YAML in policies docs (#581)
  * Generate v1 constrainttemplates by default (#585)
  * Remove all punctuation from anchors in policies.md (#565)
  * go.mod: Update
    github.com/open-policy-agent/frameworks/constraint (#577)
  * Add log-level support (#587)
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.0:
  * Use GHA directly to push container (#576)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.32.1 to
    0.32.2 (#584)
  * Fix acceptance test (#582)
  * .github: Bump regal to 0.31.0 (#580)
  * Support custom constraint (templates) (#553)
* Mon Feb 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.39.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.69.0
    to 1.1.0 (#574)
  * build(deps): bump golang from 1.23.1-alpine to 1.23.6-alpine
    (#573)
  * build(deps): bump golang.org/x/net from 0.29.0 to 0.33.0 (#570)
  * build(deps): bump alpine from 3.20.3 to 3.21.2 (#571)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.31.1 to
    0.32.1 (#572)
  * build(deps): bump golang.org/x/text from 0.18.0 to 0.22.0
    (#568)
  * ci: Add --v0-compatible flag to "opa check" (#569)
  * Use if keyword to satisfy linter requirements (#564)
  * fix: Sort parameters in docs (#554)
  * build(deps): bump github.com/open-policy-agent/opa from 0.66.0
    to 0.69.0 (#541)
  * chore: Bump Go to 1.23 (#540)
  * build(deps): bump golang.org/x/text from 0.16.0 to 0.18.0
    (#534)
  * build(deps): bump golang from 1.22.5-alpine to 1.23.1-alpine
    (#536)
  * build(deps): bump alpine from 3.20.2 to 3.20.3 (#535)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.30.3 to
    0.31.1 (#539)
  * added _ as a replacement for kind name (#537)
  * build(deps): bump alpine from 3.20.1 to 3.20.2 (#525)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.30.2 to
    0.30.3 (#524)
  * feat: update .Header.Resources to a string array (#519)
  * build(deps): bump golang from 1.22.4-alpine to 1.22.5-alpine
    (#522)
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.38.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.65.0
    to 0.66.0 (#521)
  * build(deps): bump alpine from 3.20.0 to 3.20.1 (#520)
  * build(deps): bump github.com/spf13/cobra from 1.8.0 to 1.8.1
    (#518)
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.37.0:
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.29.3 to
    0.30.2 (#515)
  * ci: Include patch version in go.mod (#517)
  * build(deps): bump golang from 1.22.3-alpine to 1.22.4-alpine
    (#514)
  * ci: Fix golangci (#500)
  * build(deps): bump golang.org/x/text from 0.15.0 to 0.16.0
    (#513)
  * build(deps): bump github.com/spf13/viper from 1.18.2 to 1.19.0
    (#512)
  * build(deps): bump github.com/open-policy-agent/opa from 0.64.1
    to 0.65.0 (#511)
  * build(deps): bump alpine from 3.19.1 to 3.20.0 (#510)
  * build(deps): bump golang from 1.22.2-alpine to 1.22.3-alpine
    (#507)
  * build(deps): bump golangci/golangci-lint-action from 5 to 6
    (#506)
  * chore: multi arch builds (#504)
  * build(deps): bump golang.org/x/text from 0.14.0 to 0.15.0
    (#501)
  * docs: Fix doc for examples and add for --no-rego.md. (#503)
  * build(deps): bump github.com/open-policy-agent/opa from 0.63.0
    to 0.64.1 (#498)
  * build(deps): bump golangci/golangci-lint-action from 4 to 5
    (#499)
  * build(deps): bump golang from 1.22.1-alpine to 1.22.2-alpine
    (#491)
* Mon Apr  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.0:
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.29.2 to
    0.29.3 (#488)
  * build(deps): bump github.com/open-policy-agent/opa from 0.62.1
    to 0.63.0 (#490)
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * Bump minimum Go version to 1.21 (#484)
  * build(deps): bump google.golang.org/protobuf from 1.32.0 to
    1.33.0 (#486)
  * build(deps): bump golang from 1.22.0-alpine to 1.22.1-alpine
    (#485)
  * build(deps): bump github.com/open-policy-agent/opa from 0.61.0
    to 0.62.1 (#483)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.29.1 to
    0.29.2 (#480)
  * build(deps): bump golang from 1.21.6-alpine to 1.22.0-alpine
    (#477)
  * build(deps): bump styrainc/setup-regal from 0.2.0 to 1.0.0
    (#478)
  * build(deps): bump golangci/golangci-lint-action from 3 to 4
    (#479)
  * build(deps): bump github.com/open-policy-agent/opa from 0.60.0
    to 0.61.0 (#475)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.29.0 to
    0.29.1 (#474)
  * build(deps): bump golang from 1.21.5-alpine to 1.21.6-alpine
    (#472)
  * build(deps): bump alpine from 3.19.0 to 3.19.1 (#476)
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.34.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.59.0
    to 0.60.0 (#470)
  * build(deps): bump actions/upload-artifact and
    actions/download-artifact from 3 to 4 (#467)
  * build(deps): bump github.com/spf13/viper from 1.18.1 to 1.18.2
    (#469)
  * build(deps): bump github.com/spf13/viper from 1.17.0 to 1.18.1
    (#461)
  * build(deps): bump golang from 1.21.4-alpine to 1.21.5-alpine
    (#462)
  * build(deps): bump alpine from 3.18.4 to 3.19.0 (#463)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.28.4 to
    0.29.0 (#466)
  * build(deps): bump actions/setup-go from 4 to 5 (#464)
* Fri Dec  1 2023 kastl@b1-systems.de
- Update to version 0.33.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.58.0
    to 0.59.0 (#458)
  * Add Regal for linting Rego (#454)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.28.3 to
    0.28.4 (#456)
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.0
    (#452)
  * build(deps): bump golang from 1.21.3-alpine to 1.21.4-alpine
    (#453)
  * build(deps): bump golang.org/x/text from 0.13.0 to 0.14.0
    (#451)
  * fix: Add missing docs (#457)
  * fix: cover empty securityContext in container_deny_escalation
    (#449)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.28.2 to
    0.28.3 (#443)
  * build(deps): bump github.com/spf13/viper from 1.16.0 to 1.17.0
    (#439)
  * build(deps): bump k8s.io/apimachinery from 0.28.2 to 0.28.3
    (#445)
  * build(deps): bump golang from 1.21.1-alpine to 1.21.3-alpine
    (#442)
  * build(deps): bump github.com/open-policy-agent/opa from 0.57.0
    to 0.58.0 (#448)
  * build(deps): bump alpine from 3.18.3 to 3.18.4 (#438)
* Mon Oct  2 2023 kastl@b1-systems.de
- Update to version 0.32.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.56.0
    to 0.57.0 (#437)
  * build(deps): bump golang.org/x/text from 0.12.0 to 0.13.0
    (#432)
  * build(deps): bump golang from 1.21.0-alpine to 1.21.1-alpine
    (#434)
  * build(deps): bump k8s.io/apiextensions-apiserver from 0.28.1 to
    0.28.2 (#435)
  * build(deps): bump actions/checkout from 3 to 4 (#433)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.31.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.55.0
    to 0.56.0 (#430)
  * fix: Fix acceptance tests after doc changes in #428 (#431)
  * feat: Support custom doc template (#428)
  * deps: Move to sigs.k8s.io/yaml (#429)
  * fix broken link to OPA Metadata Annotations (#427)
  * Bump k8s.io/apiextensions-apiserver from 0.28.0 to 0.28.1
    (#426)
  * Bump github.com/open-policy-agent/opa from 0.54.0 to 0.55.0
    (#418)
  * Bump k8s.io/apiextensions-apiserver from 0.27.3 to 0.28.0
    (#424)
  * Bump golang from 1.20.5-alpine to 1.21.0-alpine (#422)
  * Bump golang.org/x/text from 0.11.0 to 0.12.0 (#419)
  * Bump alpine from 3.18.2 to 3.18.3 (#421)
  * Bump golang.org/x/text from 0.10.0 to 0.11.0 (#414)
* Mon Jul  3 2023 kastl@b1-systems.de
- Update to version 0.30.0:
  * Bump github.com/open-policy-agent/opa from 0.53.1 to 0.54.0
    (#413)
  * Bump golang.org/x/text from 0.9.0 to 0.10.0 (#409)
  * Bump k8s.io/apiextensions-apiserver from 0.27.2 to 0.27.3
    (#411)
  * Bump alpine from 3.18.0 to 3.18.2 (#412)
  * Bump k8s.io/apimachinery from 0.27.2 to 0.27.3 (#410)
  * Bump golang from 1.20.4-alpine to 1.20.5-alpine (#408)
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.29.1:
  * Bump github.com/open-policy-agent/opa from 0.53.0 to 0.53.1
    (#407)
  * Bump github.com/sirupsen/logrus from 1.9.2 to 1.9.3 (#406)
  * Bump github.com/spf13/viper from 1.15.0 to 1.16.0 (#405)
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.29.0:
  * Bump github.com/open-policy-agent/opa from 0.52.0 to 0.53.0
    (#404)
  * Bump k8s.io/apiextensions-apiserver from 0.27.1 to 0.27.2
    (#402)
  * Bump alpine from 3.17.3 to 3.18.0 (#399)
* Mon May  8 2023 kastl@b1-systems.de
- Update to version 0.28.0:
  * build: Bump Go to 1.20.4 (#398)
  * Bump github.com/open-policy-agent/opa from 0.51.0 to 0.52.0
    (#397)
  * Bump k8s.io/apiextensions-apiserver from 0.26.3 to 0.27.1
    (#395)
  * Bump k8s.io/apimachinery from 0.26.3 to 0.27.1 (#396)
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.27.1:
  * Bump github.com/spf13/cobra from 1.6.1 to 1.7.0 (#388)
  * Bump golang from 1.20.2-alpine to 1.20.3-alpine (#392)
  * Added build step for linux/arm64 to make release (#390)
  * Bump alpine from 3.17.2 to 3.17.3 (#387)
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.27.0:
  * Bump github.com/open-policy-agent/opa from 0.50.2 to 0.51.0
    (#386)
  * ci: Bump Go in CI to 1.20.x (#373)
* Wed Mar 22 2023 kastl@b1-systems.de
- Update to version 0.26.1:
  * Bump k8s.io/apiextensions-apiserver from 0.26.2 to 0.26.3
    (#383)
  * Bump actions/setup-go from 3 to 4 (#382)
  * Bump golang from 1.20.1-alpine to 1.20.2-alpine (#380)
  * Bump k8s.io/apimachinery from 0.26.2 to 0.26.3 (#384)
  * Bump github.com/open-policy-agent/opa from 0.50.0 to 0.50.2
    (#385)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 0.26.0:
  * Bump github.com/open-policy-agent/opa from 0.49.2 to 0.50.0
    (#379)
  * Bump golang.org/x/text from 0.7.0 to 0.8.0 (#378)
  * Bump k8s.io/apiextensions-apiserver from 0.26.1 to 0.26.2
    (#377)
  * Bump k8s.io/apimachinery from 0.26.1 to 0.26.2 (#376)
  * Bump github.com/open-policy-agent/opa from 0.49.0 to 0.49.2
    (#375)
  * Bump golang from 1.19.5-alpine to 1.20.1-alpine (#372)
  * Bump golang.org/x/net from 0.5.0 to 0.7.0 (#371)
  * Bump alpine from 3.17.1 to 3.17.2 (#370)
  * Bump golang.org/x/text from 0.6.0 to 0.7.0 (#369)
* Mon Feb 27 2023 kastl@b1-systems.de
- Update to version 0.25.1:
  * Bump github.com/open-policy-agent/opa from 0.49.0 to 0.49.2 (#375)
* Wed Feb  8 2023 kastl@b1-systems.de
- Update to version 0.25.0:
  * Bump github.com/open-policy-agent/opa from 0.48.0 to 0.49.0 (#368)
  * Bump k8s.io/apiextensions-apiserver from 0.26.0 to 0.26.1 (#365)
  * Bump k8s.io/apimachinery from 0.26.0 to 0.26.1 (#364)
  * Bump github.com/spf13/viper from 1.14.0 to 1.15.0 (#363)
  * Bump golang from 1.19.4-alpine to 1.19.5-alpine (#362)
  * Bump github.com/open-policy-agent/opa from 0.47.4 to 0.48.0 (#360)
  * Bump alpine from 3.17.0 to 3.17.1 (#361)
  * Bump golang.org/x/text from 0.5.0 to 0.6.0 (#359)
  * Bump k8s.io/apiextensions-apiserver from 0.23.4 to 0.26.0 (#354)
  * Bump golang from 1.19.3-alpine to 1.19.4-alpine (#357)
  * Bump golang from 1.19.3-alpine to 1.19.4-alpine (#357)
  * Bump github.com/open-policy-agent/opa from 0.47.0 to 0.47.4 (#358)
  * Bump k8s.io/apimachinery from 0.25.4 to 0.26.0 (#355)
  * Bump alpine from 3.16.3 to 3.17.0 (#348)
  * Bump github.com/open-policy-agent/opa from 0.46.1 to 0.47.0 (#349)
  * Bump golang.org/x/text from 0.4.0 to 0.5.0 (#350)
  * Update test data to use OPA metadata (#341)
  * Use environment file for GITHUB_OUTPUT (#347)
  * Bump github.com/spf13/viper from 1.13.0 to 1.14.0 (#344)
  * Bump k8s.io/apimachinery from 0.25.3 to 0.25.4 (#345)
  * Bump alpine from 3.16.2 to 3.16.3 (#346)
  * Bump github.com/open-policy-agent/opa from 0.45.0 to 0.46.1 (#343)
  * Bump golang from 1.19.2-alpine to 1.19.3-alpine (#342)
  * Bump github.com/spf13/cobra from 1.6.0 to 1.6.1 (#340)
* Thu Oct 20 2022 kastl@b1-systems.de
- Update to version 0.24.0:
  * Bump golang.org/x/text from 0.3.8 to 0.4.0 (#339)
  * Bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#336)
  * feat: add metadata via header annotations in rego (#324)
  * Bump k8s.io/apimachinery from 0.25.2 to 0.25.3 (#338)
  * Bump golang.org/x/text from 0.3.7 to 0.3.8 (#337)
  * Bump github.com/open-policy-agent/opa from 0.44.0 to 0.45.0 (#334)
  * Bump golang from 1.19.1-alpine to 1.19.2-alpine (#335)
  * Bump k8s.io/apimachinery from 0.25.1 to 0.25.2 (#333)
  * Bump k8s.io/apimachinery from 0.25.0 to 0.25.1 (#332)
  * Update pipelines to use 1.19 (#331)
  * Bump github.com/open-policy-agent/opa from 0.43.0 to 0.44.0 (#328)
  * Bump golang from 1.18.5-alpine to 1.19.1-alpine (#329)
  * Use mod flag when updating documentation
  * Disable PSPs when installing Gatekeeper
  * Bump github.com/spf13/viper from 1.12.0 to 1.13.0 (#326)
  * Fix the description for lint in makefile (#325)
  * Bump k8s.io/apimachinery from 0.24.4 to 0.25.0 (#321)
  * Bump k8s.io/apimachinery from 0.24.3 to 0.24.4 (#320)
  * Bump alpine from 3.16.1 to 3.16.2 (#319)
  * Bump golang from 1.18.4-alpine to 1.18.5-alpine (#317)
* Mon Aug  1 2022 kastl@b1-systems.de
- Update to version 0.23.0:
  * Bump github.com/open-policy-agent/opa from 0.42.2 to 0.43.0 (#316)
  * Bump alpine from 3.16.0 to 3.16.1 (#315)
  * Bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#314)
  * Bump golang from 1.18.3-alpine to 1.18.4-alpine (#313)
* Sat Jul 16 2022 kastl@b1-systems.de
- Update to version 0.22.2:
  * Fix a bug that prevented line breaks from being output in docs when multiple parameters were specified (#311)
  * Bump github.com/open-policy-agent/opa from 0.42.1 to 0.42.2 (#310)
  * Bump k8s.io/apimachinery from 0.24.2 to 0.24.3 (#312)
  * Add Darwin arm64 build to release target
* Mon Jul 11 2022 kastl@b1-systems.de
- Update to version 0.22.1:
  * Bump github.com/open-policy-agent/opa from 0.42.0 to 0.42.1 (#309)
* Wed Jul  6 2022 kastl@b1-systems.de
- Update to version 0.22.0:
  * Add support for skip-template annotation (#307)
  * Bump github.com/open-policy-agent/opa from 0.41.0 to 0.42.0 (#306)
  * Bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#305)
  * Bump k8s.io/apimachinery from 0.24.1 to 0.24.2 (#303)
  * Bump golang from 1.18.2-alpine to 1.18.3-alpine (#300)
  * Update constraint_creation.md (#302)
  * Remove measurements lib from examples (#299)
  * Bump github.com/open-policy-agent/opa from 0.40.0 to 0.41.0 (#298)
  * Misc. verbiage fixes (#296)
* Tue May 31 2022 kastl@b1-systems.de
- Update to version 0.21.0:
  * Add command to convert legacy annotations to OPA Metadata annotations (#294)
  * Fix OPA Metadata parameters validation (fix #293) (#295)
  * Bump github.com/spf13/viper from 1.11.0 to 1.12.0 (#292)
  * Bump k8s.io/apimachinery from 0.24.0 to 0.24.1 (#291)
  * Check parent as well as exact match when resolving imports (#286)
  * Bump golang from 1.18.1-alpine to 1.18.2-alpine (#290)
  * Bump alpine from 3.15.4 to 3.16.0 (#289)
  * Have Dependabot run more often (#288)
  * Bump k8s.io/apimachinery from 0.23.6 to 0.24.0 (#285)
  * Add support for using OPA Metadata Annotations (#281)
  * Run e2e tests weekly (#284)
  * Run e2e tests weekly (#283)
  * Run e2e tests weekly (#282)
* Wed May 18 2022 kastl@b1-systems.de
- Update to version 0.20.0:
  * Parse parameter names from rule header values in addition to the body (#279)
  * Allow adding description to parameters - fix #273 (#275)
  * Group and sort kind matchers by apiGroup (fix #269) (#272)
  * Merge repeated @matchlabels and @kinds annotations (#271)
  * Fix violation rule return format in test policy (#274)
* Thu May  5 2022 kastl@b1-systems.de
- Update to version 0.19.1:
  * Bump github.com/open-policy-agent/opa from 0.39.0 to 0.40.0 (#265)
  * Bump github.com/spf13/viper from 1.10.1 to 1.11.0 (#262)
  * Bump k8s.io/apimachinery from 0.23.5 to 0.23.6 (#261)
  * Bump golang from 1.17.7-alpine to 1.18.1-alpine (#264)
  * Bump alpine from 3.15.3 to 3.15.4 (#263)
  * Fix Go linter check (#266)
  * Bump actions/upload-artifact from 2 to 3 (#260)
  * Bump actions/download-artifact from 2 to 3 (#259)
  * Bump actions/setup-go from 2 to 3 (#258)
  * Include test/ folder in e2e tests (#257)
* Thu Apr 14 2022 kastl@b1-systems.de
- Update to version 0.19.0:
  * Add @namespaces and @excludedNamespaces matchers (#255)
  * Add docs for @matchExpression, @namespaces, @excludedNamespaces annotations (#256)
  * Only parse imports prefixed with data.lib.* (#249)
  * Add support for @matchExpression label selector (#251)
  * Bump k8s.io/apimachinery from 0.23.4 to 0.23.5 (#250)
  * Bump github.com/open-policy-agent/opa from 0.38.1 to 0.39.0 (#254)
  * Bump alpine from 3.14.2 to 3.15.3 (#253)
  * Bump EndBug/add-and-commit from 8.0.2 to 9 (#246)
  * go.mod: Bump dependencies (#247)
  * Bump actions/checkout from 2 to 3 (#245)
  * Bump golang from 1.17.6-alpine to 1.17.7-alpine (#241)
  * style: Consistent policy format via conftest fmt (#239)
  * go.mod: Update to opa-0.37.2 (#240)
  * Bump EndBug/add-and-commit from 8.0.1 to 8.0.2 (#235)
- BuildRequire go1.17
* Thu Feb  3 2022 kastl@b1-systems.de
- Update to version 0.18.0:
  * Update OPA version to 0.37.1 (#234)
  * Ignore the future.keywords import (#230)
* Wed Jan 26 2022 kastl@b1-systems.de
- Update to version 0.17.0:
  * Bump Go to 1.17.6 (#227)
  * Add ability to create partial Constraint resources for policies with parameters (#225)
  * Bump EndBug/add-and-commit from 7 to 8.0.1 (#226)
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.16.0:
  * Konstraint can now generate v1 ConstraintTemplate resources with the --constraint-template-version flag. Thank you @tillepille for the contribution!
  * add flag to change constraintTemplate api version (#217)
  * Add end-to-end tests (#218)
  * Bump github.com/spf13/viper from 1.9.0 to 1.10.1 (#220)
  * Bump golang from 1.17.2-alpine to 1.17.5-alpine (#219)
  * Bump github.com/spf13/cobra from 1.2.1 to 1.3.0 (#222)
  * Install bats on MacOS runner (#216)
  * Fixed incorrect check of @parameter. Thank you @kitagry for the contribution!
  * Fix @parameter check (#215)
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.15.1:
  * Bump github.com/open-policy-agent/opa from 0.33.0 to 0.34.0 (#207)
  * Bump golang from 1.17.1-alpine to 1.17.2-alpine (#206)
  * Bump github.com/open-policy-agent/opa from 0.32.0 to 0.33.0 (#202)
  * Bump github.com/spf13/viper from 1.8.1 to 1.9.0 (#203)
  * Bump golang from 1.17.0-alpine to 1.17.1-alpine (#200)
  * docs: Fix broken link in constraint_creation.md (#199)
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.15.0:
  * Bump github.com/open-policy-agent/opa from 0.31.0 to 0.32.0 (#198)
  * Bump alpine from 3.14.0 to 3.14.2 (#195)
  * Bump golang from 1.16.6-alpine to 1.17.0-alpine (#194)
  * Bump github.com/open-policy-agent/opa from 0.30.1 to 0.31.0 (#191)
  * Bump golang from 1.16.5-alpine to 1.16.6-alpine (#190)
  * Add `--include-comments` flag for the `doc` command (#189)
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.14.2:
  * Do not parse imports on documentation generation (#187)
  * Bump OPA to v0.30.1 with bug fixes and other improvements
* Thu Jun 17 2021 kastl@b1-systems.de
- Update to version 0.14.1:
  * Support enforcement actions other than deny and dryrun (#174)
  * Remove trailing space from each line on ingest (#176)
  * Add logging to Konstraint output (#171)
* Thu Jun  3 2021 kastl@b1-systems.de
- Update to version 0.14.0:
  * Preserve whitespace (#168)
  * Add golangci linter (#167)
  * Bump golang from 1.16.3-alpine to 1.16.4-alpine (#163)
  * Bump github.com/open-policy-agent/opa from 0.28.0 to 0.29.4 (#166)
  * Replace tabs with spaces (#160)
  * Update approaches for releases (#158)
* Wed May 26 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package konstraint
